@@ -30,12 +30,15 @@ class EngineTrainer(engine.Engine):
         self.world_size = comm.get_world_size()
         self.local_rank = comm.get_local_rank()
         self.device = comm.get_device(cfg.gpu_id)
+        self.num_steps = 0
+        self.num_samples = 0
 
     def build(self, cfg, **kwargs):
         self.train_loader = self.build_train_loader(cfg, **kwargs)
         self.test_loader = self.build_test_loader(cfg, **kwargs)
-        self.num_steps = len(self.train_loader)
-        self.num_samples = len(self.train_loader.sampler)
+        if self.train_loader:
+            self.num_steps = len(self.train_loader)
+            self.num_samples = len(self.train_loader.sampler)
         self.model = self.build_model(cfg, **kwargs)
         self.optimizer = self.build_optimizer(cfg, **kwargs)
         self.criterion = self.build_criterion(cfg, **kwargs)
