@@ -40,7 +40,13 @@ def parser_config(args, cfg_updata=True):
             cfg = args.__dict__
             cfg['config_file'] = save_config(cfg, 'args_config.yaml')
     else:
-        cfg = args.__dict__
+        try:
+            cfg = load_config(args.config_file)
+            cfg = dict(cfg, **args.__dict__)
+            cfg["config_file"] = args.config_file
+        except:
+            cfg = args.__dict__
+            cfg['config_file'] = save_config(cfg, 'args_config.yaml')
     print_dict(cfg)
     cfg = easydict.EasyDict(cfg)
     return cfg
